@@ -33,17 +33,16 @@ const (
 
 // @Description CronConfig
 type Blueprint struct {
-	Name        string          `json:"name" validate:"required"`
-	ProjectName string          `json:"projectName" gorm:"type:varchar(255)"`
-	Mode        string          `json:"mode" gorm:"varchar(20)" validate:"required,oneof=NORMAL ADVANCED"`
-	Plan        json.RawMessage `json:"plan" gorm:"serializer:encdec"`
-	Enable      bool            `json:"enable"`
-	//please check this https://crontab.guru/ for detail
-	CronConfig   string          `json:"cronConfig" format:"* * * * *" example:"0 0 * * 1"`
-	IsManual     bool            `json:"isManual"`
-	SkipOnFail   bool            `json:"skipOnFail"`
-	Labels       []string        `json:"labels" gorm:"-"`
-	Settings     json.RawMessage `json:"settings" swaggertype:"array,string" example:"please check api: /blueprints/<PLUGIN_NAME>/blueprint-setting" gorm:"serializer:encdec"`
+	Name         string              `json:"name" validate:"required"`
+	ProjectName  string              `json:"projectName" gorm:"type:varchar(255)"`
+	Mode         string              `json:"mode" gorm:"varchar(20)" validate:"required,oneof=NORMAL ADVANCED"`
+	Plan         plugin.PipelinePlan `json:"plan" gorm:"serializer:encdec"`
+	Enable       bool                `json:"enable"`
+	CronConfig   string              `json:"cronConfig" format:"* * * * *" example:"0 0 * * 1"`
+	IsManual     bool                `json:"isManual"`
+	SkipOnFail   bool                `json:"skipOnFail"`
+	Labels       []string            `json:"labels" gorm:"-"`
+	Settings     json.RawMessage     `json:"settings" swaggertype:"array,string" example:"please check api: /blueprints/<PLUGIN_NAME>/blueprint-setting" gorm:"serializer:encdec"`
 	common.Model `swaggerignore:"true"`
 }
 
@@ -91,16 +90,6 @@ func (bps *BlueprintSettings) UpdateConnections(updater func(c *plugin.Blueprint
 	return nil
 }
 
-// UnmarshalPlan unmarshals Plan in JSON to strong-typed plugin.PipelinePlan
-func (bp *Blueprint) UnmarshalPlan() (plugin.PipelinePlan, errors.Error) {
-	var plan plugin.PipelinePlan
-	err := errors.Convert(json.Unmarshal(bp.Plan, &plan))
-	if err != nil {
-		return nil, errors.Default.Wrap(err, `unmarshal plan fail`)
-	}
-	return plan, nil
-}
-
 // UnmarshalSettings unmarshals the BlueprintSettings on the Blueprint
 func (bp *Blueprint) UnmarshalSettings() (BlueprintSettings, errors.Error) {
 	var settings BlueprintSettings
