@@ -18,6 +18,7 @@ limitations under the License.
 package api
 
 import (
+	"fmt"
 	"strings"
 
 	"github.com/apache/incubator-devlake/core/models/common"
@@ -29,6 +30,10 @@ type BaseConnection struct {
 	common.Model
 }
 
+func (c BaseConnection) GetHash() string {
+	return fmt.Sprintf("%d%v", c.ID, c.UpdatedAt)
+}
+
 // RestConnection implements the ApiConnection interface
 type RestConnection struct {
 	Endpoint         string `mapstructure:"endpoint" validate:"required" json:"endpoint"`
