@@ -67,6 +67,10 @@ type (
 		Scope                    Scope                    `mapstructure:",squash"` // ideally we need this field to be embedded in the struct
 		ScopeResDoc[ScopeConfig] `mapstructure:",squash"` // however, only this type of embeding is supported as of golang 1.20
 	}
+	ScopeListRes[Scope plugin.ToolLayerScope, ScopeConfig any] struct {
+		Scopes []*ScopeRes[Scope, ScopeConfig] `mapstructure:"scopes" json:"scopes"`
+		Count  int64                           `mapstructure:"count" json:"count"`
+	}
 	ReflectionParameters struct {
 		// This corresponds to the struct field of the scope struct's ID field
 		ScopeIdFieldName string `validate:"required"`
@@ -74,6 +78,8 @@ type (
 		ScopeIdColumnName string `validate:"required"`
 		// This corresponds to the scope field on the ApiParams struct of a plugin.
 		RawScopeParamName string `validate:"required"`
+		// This corresponds to the scope field for allowing data scope search.
+		SearchScopeParamName string
 	}
 	ScopeHelperOptions struct {
 		// Define this if the raw params doesn't store the ScopeId but a different attribute of the Scope (e.g. Name)
@@ -168,7 +174,7 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) PutScopes(input *plug
 	}
 	now := time.Now()
 	for _, scope := range scopes {
-		// Set the connection ID, CreatedDate, and UpdatedDate fields
+		// Set the connection ID, CreatedAt, and UpdatedAt fields
 		gs.setScopeFields(scope, params.connectionId, &now, &now)
 		err = gs.verifyScope(scope, gs.validator)
 		if err != nil {
@@ -223,7 +229,7 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) UpdateScope(input *pl
 	return scopeRes[0], nil
 }
 
-func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScopes(input *plugin.ApiResourceInput) ([]*ScopeRes[Scope, ScopeConfig], errors.Error) {
+func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScopes(input *plugin.ApiResourceInput) (*ScopeListRes[Scope, ScopeConfig], errors.Error) {
 	params, err := gs.extractFromGetReqParam(input, false)
 	if err != nil {
 		return nil, errors.BadInput.New("invalid path params: \"connectionId\" not set")
@@ -232,9 +238,9 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScopes(input *plug
 	if err != nil {
 		return nil, errors.Default.Wrap(err, fmt.Sprintf("error verifying connection for connection ID %d", params.connectionId))
 	}
-	scopes, err := gs.dbHelper.ListScopes(input, params.connectionId)
+	scopes, count, err := gs.dbHelper.ListScopes(input, params.connectionId)
 	if err != nil {
-		return nil, errors.Default.Wrap(err, fmt.Sprintf("error verifying connection for connection ID %d", params.connectionId))
+		return nil, err
 	}
 	apiScopes, err := gs.addScopeConfig(scopes...)
 	if err != nil {
@@ -264,7 +270,10 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScopes(input *plug
 			gs.log.Warn(nil, "The following dangling scopes were found: %v", danglingIds)
 		}
 	}
-	return apiScopes, nil
+	return &ScopeListRes[Scope, ScopeConfig]{
+		Scopes: apiScopes,
+		Count:  count,
+	}, nil
 }
 
 func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScope(input *plugin.ApiResourceInput) (*ScopeRes[Scope, ScopeConfig], errors.Error) {
@@ -450,7 +459,7 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) createRawParams(conne
 	return plugin.MarshalScopeParams(paramsMap)
 }
 
-func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) setScopeFields(p interface{}, connectionId uint64, createdDate *time.Time, updatedDate *time.Time) {
+func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) setScopeFields(p interface{}, connectionId uint64, createdAt *time.Time, updatedAt *time.Time) {
 	pType := reflect.TypeOf(p)
 	if pType.Kind() != reflect.Ptr {
 		panic("expected a pointer to a struct")
@@ -468,24 +477,24 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) setScopeFields(p inte
 	scopeIdField := pValue.FieldByName(gs.reflectionParams.ScopeIdFieldName)
 	rawParams.Set(reflect.ValueOf(gs.createRawParams(connectionId, scopeIdField.Interface())))
 
-	// set CreatedDate
-	createdDateField := pValue.FieldByName("CreatedDate")
-	if createdDateField.IsValid() && createdDateField.Type().AssignableTo(reflect.TypeOf(createdDate)) {
-		createdDateField.Set(reflect.ValueOf(createdDate))
+	// set CreatedAt
+	createdAtField := pValue.FieldByName("CreatedAt")
+	if createdAtField.IsValid() && createdAtField.Type().AssignableTo(reflect.TypeOf(createdAt)) {
+		createdAtField.Set(reflect.ValueOf(createdAt))
 	}
 
-	// set UpdatedDate
-	updatedDateField := pValue.FieldByName("UpdatedDate")
-	if !updatedDateField.IsValid() || (updatedDate != nil && !updatedDateField.Type().AssignableTo(reflect.TypeOf(updatedDate))) {
+	// set UpdatedAt
+	updatedAtField := pValue.FieldByName("UpdatedAt")
+	if !updatedAtField.IsValid() || (updatedAt != nil && !updatedAtField.Type().AssignableTo(reflect.TypeOf(updatedAt))) {
 		return
 	}
-	if updatedDate == nil {
-		// if updatedDate is nil, set UpdatedDate to be nil
-		updatedDateField.Set(reflect.Zero(updatedDateField.Type()))
+	if updatedAt == nil {
+		// if updatedAt is nil, set UpdatedAt to be nil
+		updatedAtField.Set(reflect.Zero(updatedAtField.Type()))
 	} else {
-		// if updatedDate is not nil, set UpdatedDate to be the value
-		updatedDateFieldValue := reflect.ValueOf(updatedDate)
-		updatedDateField.Set(updatedDateFieldValue)
+		// if updatedAt is not nil, set UpdatedAt to be the value
+		updatedAtFieldValue := reflect.ValueOf(updatedAt)
+		updatedAtField.Set(updatedAtFieldValue)
 	}
 }
 
