@@ -18,6 +18,7 @@ limitations under the License.
 package api
 
 import (
+	"encoding/json"
 	"fmt"
 	"reflect"
 	"testing"
@@ -31,7 +32,6 @@ import (
 	"github.com/go-playground/validator/v10"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
-	"gorm.io/datatypes"
 	"gorm.io/gorm"
 )
 
@@ -162,19 +162,19 @@ func TestVerifyScope(t *testing.T) {
 
 type TestScopeConfig struct {
 	common.Model         `mapstructure:"-"`
-	Name                 string            `mapstructure:"name" json:"name" gorm:"type:varchar(255);index:idx_name_github,unique" validate:"required"`
-	PrType               string            `mapstructure:"prType,omitempty" json:"prType" gorm:"type:varchar(255)"`
-	PrComponent          string            `mapstructure:"prComponent,omitempty" json:"prComponent" gorm:"type:varchar(255)"`
-	PrBodyClosePattern   string            `mapstructure:"prBodyClosePattern,omitempty" json:"prBodyClosePattern" gorm:"type:varchar(255)"`
-	IssueSeverity        string            `mapstructure:"issueSeverity,omitempty" json:"issueSeverity" gorm:"type:varchar(255)"`
-	IssuePriority        string            `mapstructure:"issuePriority,omitempty" json:"issuePriority" gorm:"type:varchar(255)"`
-	IssueComponent       string            `mapstructure:"issueComponent,omitempty" json:"issueComponent" gorm:"type:varchar(255)"`
-	IssueTypeBug         string            `mapstructure:"issueTypeBug,omitempty" json:"issueTypeBug" gorm:"type:varchar(255)"`
-	IssueTypeIncident    string            `mapstructure:"issueTypeIncident,omitempty" json:"issueTypeIncident" gorm:"type:varchar(255)"`
-	IssueTypeRequirement string            `mapstructure:"issueTypeRequirement,omitempty" json:"issueTypeRequirement" gorm:"type:varchar(255)"`
-	DeploymentPattern    string            `mapstructure:"deploymentPattern,omitempty" json:"deploymentPattern" gorm:"type:varchar(255)"`
-	ProductionPattern    string            `mapstructure:"productionPattern,omitempty" json:"productionPattern" gorm:"type:varchar(255)"`
-	Refdiff              datatypes.JSONMap `mapstructure:"refdiff,omitempty" json:"refdiff" swaggertype:"object" format:"json"`
+	Name                 string          `mapstructure:"name" json:"name" gorm:"type:varchar(255);index:idx_name_github,unique" validate:"required"`
+	PrType               string          `mapstructure:"prType,omitempty" json:"prType" gorm:"type:varchar(255)"`
+	PrComponent          string          `mapstructure:"prComponent,omitempty" json:"prComponent" gorm:"type:varchar(255)"`
+	PrBodyClosePattern   string          `mapstructure:"prBodyClosePattern,omitempty" json:"prBodyClosePattern" gorm:"type:varchar(255)"`
+	IssueSeverity        string          `mapstructure:"issueSeverity,omitempty" json:"issueSeverity" gorm:"type:varchar(255)"`
+	IssuePriority        string          `mapstructure:"issuePriority,omitempty" json:"issuePriority" gorm:"type:varchar(255)"`
+	IssueComponent       string          `mapstructure:"issueComponent,omitempty" json:"issueComponent" gorm:"type:varchar(255)"`
+	IssueTypeBug         string          `mapstructure:"issueTypeBug,omitempty" json:"issueTypeBug" gorm:"type:varchar(255)"`
+	IssueTypeIncident    string          `mapstructure:"issueTypeIncident,omitempty" json:"issueTypeIncident" gorm:"type:varchar(255)"`
+	IssueTypeRequirement string          `mapstructure:"issueTypeRequirement,omitempty" json:"issueTypeRequirement" gorm:"type:varchar(255)"`
+	DeploymentPattern    string          `mapstructure:"deploymentPattern,omitempty" json:"deploymentPattern" gorm:"type:varchar(255)"`
+	ProductionPattern    string          `mapstructure:"productionPattern,omitempty" json:"productionPattern" gorm:"type:varchar(255)"`
+	Refdiff              json.RawMessage `mapstructure:"refdiff,omitempty" json:"refdiff" swaggertype:"object" format:"json"`
 }
 
 func (TestScopeConfig) TableName() string {
@@ -184,11 +184,10 @@ func (TestScopeConfig) TableName() string {
 func TestSetScopeFields(t *testing.T) {
 	// create a struct
 	type P struct {
-		ConnectionId uint64 `json:"connectionId" mapstructure:"connectionId" gorm:"primaryKey"`
-		GitlabId     int    `json:"gitlabId" mapstructure:"gitlabId" gorm:"primaryKey"`
-
-		CreatedDate      *time.Time `json:"createdDate" mapstructure:"-"`
-		UpdatedDate      *time.Time `json:"updatedDate" mapstructure:"-"`
+		ConnectionId     uint64     `json:"connectionId" mapstructure:"connectionId" gorm:"primaryKey"`
+		GitlabId         int        `json:"gitlabId" mapstructure:"gitlabId" gorm:"primaryKey"`
+		CreatedAt        *time.Time `json:"createdAt" mapstructure:"-"`
+		UpdatedAt        *time.Time `json:"updatedAt" mapstructure:"-"`
 		common.NoPKModel `json:"-" mapstructure:"-"`
 	}
 	p := P{}
@@ -196,38 +195,38 @@ func TestSetScopeFields(t *testing.T) {
 
 	// call setScopeFields to assign value
 	connectionId := uint64(123)
-	createdDate := time.Now()
-	updatedDate := &createdDate
-	apiHelper.setScopeFields(&p, connectionId, &createdDate, updatedDate)
+	createdAt := time.Now()
+	updatedAt := &createdAt
+	apiHelper.setScopeFields(&p, connectionId, &createdAt, updatedAt)
 
 	// verify fields
 	if p.ConnectionId != connectionId {
 		t.Errorf("ConnectionId not set correctly, expected: %v, got: %v", connectionId, p.ConnectionId)
 	}
 
-	if !p.CreatedDate.Equal(createdDate) {
-		t.Errorf("CreatedDate not set correctly, expected: %v, got: %v", createdDate, p.CreatedDate)
+	if !p.CreatedAt.Equal(createdAt) {
+		t.Errorf("CreatedAt not set correctly, expected: %v, got: %v", createdAt, p.CreatedAt)
 	}
 
-	if p.UpdatedDate == nil {
-		t.Errorf("UpdatedDate not set correctly, expected: %v, got: %v", updatedDate, p.UpdatedDate)
-	} else if !p.UpdatedDate.Equal(*updatedDate) {
-		t.Errorf("UpdatedDate not set correctly, expected: %v, got: %v", updatedDate, p.UpdatedDate)
+	if p.UpdatedAt == nil {
+		t.Errorf("UpdatedDate not set correctly, expected: %v, got: %v", updatedAt, p.UpdatedAt)
+	} else if !p.UpdatedAt.Equal(*updatedAt) {
+		t.Errorf("UpdatedDate not set correctly, expected: %v, got: %v", updatedAt, p.UpdatedAt)
 	}
 
-	apiHelper.setScopeFields(&p, connectionId, &createdDate, nil)
+	apiHelper.setScopeFields(&p, connectionId, &createdAt, nil)
 
 	// verify fields
 	if p.ConnectionId != connectionId {
 		t.Errorf("ConnectionId not set correctly, expected: %v, got: %v", connectionId, p.ConnectionId)
 	}
 
-	if !p.CreatedDate.Equal(createdDate) {
-		t.Errorf("CreatedDate not set correctly, expected: %v, got: %v", createdDate, p.CreatedDate)
+	if !p.CreatedAt.Equal(createdAt) {
+		t.Errorf("CreatedDate not set correctly, expected: %v, got: %v", createdAt, p.CreatedAt)
 	}
 
-	if p.UpdatedDate != nil {
-		t.Errorf("UpdatedDate not set correctly, expected: %v, got: %v", nil, p.UpdatedDate)
+	if p.UpdatedAt != nil {
+		t.Errorf("UpdatedDate not set correctly, expected: %v, got: %v", nil, p.UpdatedAt)
 	}
 }
 
