@@ -18,8 +18,6 @@ limitations under the License.
 package e2e
 
 import (
-	"testing"
-
 	"github.com/apache/incubator-devlake/core/models/common"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/devops"
 	"github.com/apache/incubator-devlake/helpers/e2ehelper"
@@ -27,33 +25,46 @@ import (
 	"github.com/apache/incubator-devlake/plugins/bamboo/impl"
 	"github.com/apache/incubator-devlake/plugins/bamboo/models"
 	"github.com/apache/incubator-devlake/plugins/bamboo/tasks"
+	"testing"
+	"time"
 )
 
+func getFakeAPIClient() *helper.ApiAsyncClient {
+	client := &helper.ApiClient{}
+	client.Setup("http://127.0.0.1:8080/bamboo/", nil, time.Second)
+	return &helper.ApiAsyncClient{
+		ApiClient: client,
+	}
+}
+
 func TestBambooDeployBuildDataFlow(t *testing.T) {
 	var bamboo impl.Bamboo
 	dataflowTester := e2ehelper.NewDataFlowTester(t, "bamboo", bamboo)
 	taskData := &tasks.BambooTaskData{
 		Options: &models.BambooOptions{
 			ConnectionId: 1,
-			ProjectKey:   "TEST1",
+			PlanKey:      "TEST-PLA2",
 			BambooScopeConfig: &models.BambooScopeConfig{
 				DeploymentPattern: "(?i)release",
 				ProductionPattern: "(?i)release",
 			},
 		},
 		RegexEnricher: helper.NewRegexEnricher(),
+		ApiClient:     getFakeAPIClient(),
 	}
 	taskData.RegexEnricher.TryAdd(devops.DEPLOYMENT, taskData.Options.DeploymentPattern)
 	taskData.RegexEnricher.TryAdd(devops.PRODUCTION, taskData.Options.ProductionPattern)
 	// import raw data table
-	dataflowTester.ImportCsvIntoRawTable("./raw_tables/_raw_bamboo_api_deploy_build.csv", "_raw_bamboo_api_deploy_build")
+	dataflowTester.ImportCsvIntoRawTable("./raw_tables/_raw_bamboo_api_deploy_builds.csv", "_raw_bamboo_api_deploy_builds")
 
 	// verify extraction
 	dataflowTester.FlushTabler(&models.BambooDeployBuild{})
+	dataflowTester.FlushTabler(&models.BambooPlanBuildVcsRevision{})
 	dataflowTester.Subtask(tasks.ExtractDeployBuildMeta, taskData)
+
 	dataflowTester.VerifyTable(
 		models.BambooDeployBuild{},
-		"./snapshot_tables/_tool_bamboo_deploy_build.csv",
+		"./snapshot_tables/_tool_bamboo_deploy_builds.csv",
 		e2ehelper.ColumnWithRawData(
 			"connection_id",
 			"deploy_build_id",
@@ -79,10 +90,14 @@ func TestBambooDeployBuildDataFlow(t *testing.T) {
 	)
 
 	// verify conversion
-	dataflowTester.FlushTabler(&devops.CICDTask{})
+	dataflowTester.ImportCsvIntoTabler("./snapshot_tables/_tool_bamboo_plan_build_commits.csv", &models.BambooPlanBuildVcsRevision{})
+	dataflowTester.ImportCsvIntoTabler("./snapshot_tables/_tool_bamboo_deploy_builds.csv", &models.BambooDeployBuild{})
+	dataflowTester.ImportCsvIntoTabler("./snapshot_tables/_tool_bamboo_plans.csv", models.BambooPlan{})
+	dataflowTester.FlushTabler(&devops.CicdDeploymentCommit{})
 	dataflowTester.Subtask(tasks.ConvertDeployBuildsMeta, taskData)
-	dataflowTester.VerifyTableWithOptions(&devops.CICDTask{}, e2ehelper.TableOptions{
-		CSVRelPath:  "./snapshot_tables/cicd_tasks_deploy.csv",
-		IgnoreTypes: []interface{}{common.NoPKModel{}},
+	dataflowTester.VerifyTableWithOptions(&devops.CicdDeploymentCommit{}, e2ehelper.TableOptions{
+		CSVRelPath:   "./snapshot_tables/cicd_deployment_commits.csv",
+		IgnoreTypes:  []interface{}{common.NoPKModel{}},
+		IgnoreFields: []string{},
 	})
 }
