@@ -29,5 +29,12 @@ func All() []plugin.MigrationScript {
 		new(addTypeAndEnvironment),
 		new(renameTr2ScopeConfig),
 		new(addRawParamTableForScope),
+		new(addScopeConfigId),
+		new(addEnvNamePattern),
+		new(addPlanResultKey),
+		new(renameToolBambooDeployBuild20230919),
+		new(renameToolBambooDeployEnvironments20230919),
+		new(renameMultiBambooRawTables20230920),
+		new(addMissingPrimaryKeyForBambooPlanBuildVcsRevision),
 	}
 }
