@@ -67,7 +67,7 @@ func ConvertPullRequestComments(taskCtx plugin.SubTaskContext) errors.Error {
 				},
 				PullRequestId: prIdGen.Generate(prComment.ConnectionId, prComment.RepoId, prComment.PullRequestId),
 				AccountId:     accountIdGen.Generate(prComment.ConnectionId, prComment.AuthorId),
-				CreatedDate:   prComment.CreatedAt,
+				CreatedDate:   prComment.BitbucketCreatedAt,
 				Body:          prComment.Body,
 				Type:          prComment.Type,
 				CommitSha:     "",
