@@ -30,12 +30,28 @@ import (
 	"github.com/apache/incubator-devlake/plugins/github/models"
 )
 
+func init() {
+	RegisterSubtaskMeta(&CollectAccountsMeta)
+}
+
 const RAW_ACCOUNT_TABLE = "github_api_accounts"
 
 type SimpleAccount struct {
 	Login string
 }
 
+var CollectAccountsMeta = plugin.SubTaskMeta{
+	Name:             "collectAccounts",
+	EntryPoint:       CollectAccounts,
+	EnabledByDefault: true,
+	Description:      "Collect accounts data from Github api, does not support either timeFilter or diffSync.",
+	DomainTypes:      []string{plugin.DOMAIN_TYPE_CROSS},
+	DependencyTables: []string{
+		//models.GithubRepoAccount{}.TableName() // cursor, config will not regard as dependency
+	},
+	ProductTables: []string{RAW_ACCOUNT_TABLE},
+}
+
 func CollectAccounts(taskCtx plugin.SubTaskContext) errors.Error {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*GithubTaskData)
@@ -85,11 +101,3 @@ func CollectAccounts(taskCtx plugin.SubTaskContext) errors.Error {
 	}
 	return collector.Execute()
 }
-
-var CollectAccountsMeta = plugin.SubTaskMeta{
-	Name:             "collectAccounts",
-	EntryPoint:       CollectAccounts,
-	EnabledByDefault: true,
-	Description:      "Collect accounts data from Github api, does not support either timeFilter or diffSync.",
-	DomainTypes:      []string{plugin.DOMAIN_TYPE_CROSS},
-}
