@@ -30,12 +30,23 @@ import (
 	"github.com/apache/incubator-devlake/plugins/github/models"
 )
 
+func init() {
+	RegisterSubtaskMeta(&ConvertJobsMeta)
+}
+
 var ConvertJobsMeta = plugin.SubTaskMeta{
 	Name:             "convertJobs",
 	EntryPoint:       ConvertJobs,
 	EnabledByDefault: true,
 	Description:      "Convert tool layer table github_jobs into  domain layer table cicd_tasks",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_CICD},
+	DependencyTables: []string{
+		RAW_JOB_TABLE,
+		models.GithubJob{}.TableName(), // cursor and generator
+		models.GithubRun{}.TableName(), // id generator
+		//models.GithubRepo{}.TableName(), // id generator, but config will not regard as dependency
+	},
+	ProductTables: []string{devops.CICDTask{}.TableName()},
 }
 
 type SimpleBranch struct {
@@ -86,9 +97,9 @@ func ConvertJobs(taskCtx plugin.SubTaskContext) (err errors.Error) {
 				Type:         line.Type,
 				Environment:  line.Environment,
 				Result: devops.GetResult(&devops.ResultRule{
-					Failed:  []string{"failure", "FAILURE"},
-					Success: []string{"success", "SUCCESS"},
-					Skipped: []string{"skipped", "SKIPPED"},
+					Failed:  []string{"failure"},
+					Success: []string{"success"},
+					Skipped: []string{"skipped", "NEUTRAL"},
 				}, line.Conclusion),
 				Status: devops.GetStatus(&devops.StatusRule[string]{
 					Done:    []string{"completed", "COMPLETED"},
