@@ -28,8 +28,22 @@ import (
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
+func init() {
+	RegisterSubtaskMeta(&CollectApiCommentsMeta)
+}
+
 const RAW_COMMENTS_TABLE = "github_api_comments"
 
+var CollectApiCommentsMeta = plugin.SubTaskMeta{
+	Name:             "collectApiComments",
+	EntryPoint:       CollectApiComments,
+	EnabledByDefault: true,
+	Description:      "Collect comments data from Github api, supports both timeFilter and diffSync.",
+	DomainTypes:      []string{plugin.DOMAIN_TYPE_CODE_REVIEW, plugin.DOMAIN_TYPE_TICKET},
+	DependencyTables: []string{},
+	ProductTables:    []string{RAW_COMMENTS_TABLE},
+}
+
 func CollectApiComments(taskCtx plugin.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*GithubTaskData)
 	collectorWithState, err := helper.NewStatefulApiCollector(helper.RawDataSubTaskArgs{
@@ -87,11 +101,3 @@ func CollectApiComments(taskCtx plugin.SubTaskContext) errors.Error {
 
 	return collectorWithState.Execute()
 }
-
-var CollectApiCommentsMeta = plugin.SubTaskMeta{
-	Name:             "collectApiComments",
-	EntryPoint:       CollectApiComments,
-	EnabledByDefault: true,
-	Description:      "Collect comments data from Github api, supports both timeFilter and diffSync.",
-	DomainTypes:      []string{plugin.DOMAIN_TYPE_CODE_REVIEW, plugin.DOMAIN_TYPE_TICKET},
-}
