@@ -30,12 +30,22 @@ import (
 	"github.com/apache/incubator-devlake/plugins/github/models"
 )
 
+func init() {
+	RegisterSubtaskMeta(&ConvertIssueCommentsMeta)
+}
+
 var ConvertIssueCommentsMeta = plugin.SubTaskMeta{
 	Name:             "convertIssueComments",
 	EntryPoint:       ConvertIssueComments,
 	EnabledByDefault: true,
 	Description:      "ConvertIssueComments data from Github api",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_TICKET},
+	DependencyTables: []string{
+		models.GithubIssueComment{}.TableName(), // cursor
+		models.GithubIssue{}.TableName(),        // cursor and id generator
+		models.GithubAccount{}.TableName(),      // id generator
+		RAW_COMMENTS_TABLE},
+	ProductTables: []string{ticket.IssueComment{}.TableName()},
 }
 
 func ConvertIssueComments(taskCtx plugin.SubTaskContext) errors.Error {
