@@ -28,10 +28,24 @@ import (
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
+func init() {
+	RegisterSubtaskMeta(&CollectApiPrReviewCommentsMeta)
+}
+
 const RAW_PR_REVIEW_COMMENTS_TABLE = "github_api_pull_request_review_comments"
 
 // this struct should be moved to `github_api_common.go`
 
+var CollectApiPrReviewCommentsMeta = plugin.SubTaskMeta{
+	Name:             "collectApiPrReviewCommentsMeta",
+	EntryPoint:       CollectPrReviewComments,
+	EnabledByDefault: true,
+	Description:      "Collect pr review comments data from Github api, supports both timeFilter and diffSync.",
+	DomainTypes:      []string{plugin.DOMAIN_TYPE_CROSS, plugin.DOMAIN_TYPE_CODE_REVIEW},
+	DependencyTables: []string{},
+	ProductTables:    []string{RAW_PR_REVIEW_COMMENTS_TABLE},
+}
+
 func CollectPrReviewComments(taskCtx plugin.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*GithubTaskData)
 
@@ -52,6 +66,12 @@ func CollectPrReviewComments(taskCtx plugin.SubTaskContext) errors.Error {
 		ApiClient:   data.ApiClient,
 		PageSize:    100,
 		Incremental: incremental,
+		Header: func(reqData *helper.RequestData) (http.Header, errors.Error) {
+			// Adding -H "Accept: application/vnd.github+json" solve the issue of getting 502/403 error
+			header := http.Header{}
+			header.Set("Accept", "application/vnd.github+json")
+			return header, nil
+		},
 
 		UrlTemplate: "repos/{{ .Params.Name }}/pulls/comments",
 		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
@@ -88,11 +108,3 @@ func CollectPrReviewComments(taskCtx plugin.SubTaskContext) errors.Error {
 
 	return collectorWithState.Execute()
 }
-
-var CollectApiPrReviewCommentsMeta = plugin.SubTaskMeta{
-	Name:             "collectApiPrReviewCommentsMeta",
-	EntryPoint:       CollectPrReviewComments,
-	EnabledByDefault: true,
-	Description:      "Collect pr review comments data from Github api, supports both timeFilter and diffSync.",
-	DomainTypes:      []string{plugin.DOMAIN_TYPE_CROSS, plugin.DOMAIN_TYPE_CODE_REVIEW},
-}
