@@ -121,16 +121,11 @@ func PatchConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput,
 // @Tags plugins/gitlab
 // @Success 200  {object} models.GitlabConnection
 // @Failure 400  {string} errcode.Error "Bad Request"
+// @Failure 409  {object} services.BlueprintProjectPairs "References exist to this connection"
 // @Failure 500  {string} errcode.Error "Internal Error"
 // @Router /plugins/gitlab/connections/{connectionId} [DELETE]
 func DeleteConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
-	connection := &models.GitlabConnection{}
-	err := connectionHelper.First(connection, input.Params)
-	if err != nil {
-		return nil, err
-	}
-	err = connectionHelper.Delete(connection)
-	return &plugin.ApiResourceOutput{Body: connection}, err
+	return connectionHelper.Delete(&models.GitlabConnection{}, input)
 }
 
 // @Summary get all gitlab connections
@@ -164,25 +159,3 @@ func GetConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, e
 	}
 	return &plugin.ApiResourceOutput{Body: connection}, err
 }
-
-// @Summary pipelines plan for gitlab
-// @Description pipelines plan for gitlab
-// @Tags plugins/gitlab
-// @Accept application/json
-// @Param blueprint body GitlabPipelinePlan true "json"
-// @Router /pipelines/gitlab/pipeline-plan [post]
-func PostGitlabPipeline(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
-	blueprint := &GitlabPipelinePlan{}
-	return &plugin.ApiResourceOutput{Body: blueprint, Status: http.StatusOK}, nil
-}
-
-type GitlabPipelinePlan [][]struct {
-	Plugin   string   `json:"plugin"`
-	Subtasks []string `json:"subtasks"`
-	Options  struct {
-		ConnectionID   int `json:"connectionId"`
-		ProjectId      int `json:"projectId"`
-		Since          string
-		Transformation models.GitlabTransformationRule `json:"transformation"`
-	} `json:"options"`
-}
