@@ -27,6 +27,10 @@ import (
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
+func init() {
+	RegisterSubtaskMeta(&CollectApiPipelinesMeta)
+}
+
 const RAW_PIPELINE_TABLE = "gitlab_api_pipeline"
 
 var CollectApiPipelinesMeta = plugin.SubTaskMeta{
@@ -35,6 +39,7 @@ var CollectApiPipelinesMeta = plugin.SubTaskMeta{
 	EnabledByDefault: true,
 	Description:      "Collect pipeline data from gitlab api, supports both timeFilter and diffSync.",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_CICD},
+	Dependencies:     []*plugin.SubTaskMeta{&ExtractApiMrCommitsMeta},
 }
 
 func CollectApiPipelines(taskCtx plugin.SubTaskContext) errors.Error {
