@@ -123,16 +123,11 @@ func PatchConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput,
 // @Tags plugins/jenkins
 // @Success 200  {object} models.JenkinsConnection
 // @Failure 400  {string} errcode.Error "Bad Request"
+// @Failure 409  {object} services.BlueprintProjectPairs "References exist to this connection"
 // @Failure 500  {string} errcode.Error "Internal Error"
 // @Router /plugins/jenkins/connections/{connectionId} [DELETE]
 func DeleteConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
-	connection := &models.JenkinsConnection{}
-	err := connectionHelper.First(connection, input.Params)
-	if err != nil {
-		return nil, err
-	}
-	err = connectionHelper.Delete(connection)
-	return &plugin.ApiResourceOutput{Body: connection}, err
+	return connectionHelper.Delete(&models.JenkinsConnection{}, input)
 }
 
 // @Summary get all jenkins connections
@@ -167,46 +162,3 @@ func GetConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, e
 	}
 	return &plugin.ApiResourceOutput{Body: connection}, err
 }
-
-// @Summary blueprints setting for jenkins
-// @Description blueprint setting for jenkins
-// @Tags plugins/jenkins
-// @Accept application/json
-// @Param blueprint body JenkinsBlueprintSetting true "json"
-// @Router /blueprints/jenkins/blueprint-setting [post]
-func PostJenkinsBluePrint(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
-	blueprint := &JenkinsBlueprintSetting{}
-	return &plugin.ApiResourceOutput{Body: blueprint, Status: http.StatusOK}, nil
-}
-
-type JenkinsBlueprintSetting []struct {
-	Version     string `json:"version"`
-	Connections []struct {
-		Plugin       string `json:"plugin"`
-		ConnectionID int    `json:"connectionId"`
-		Scope        []struct {
-			Options struct {
-			} `json:"options"`
-			Entities []string `json:"entities"`
-		} `json:"scopes"`
-	} `json:"connections"`
-}
-
-// @Summary pipelines plan for jenkins
-// @Description pipelines plan for jenkins
-// @Tags plugins/jenkins
-// @Accept application/json
-// @Param blueprint body JenkinsPipelinePlan true "json"
-// @Router /pipelines/jenkins/pipeline-plan [post]
-func PostJenkinsPipeline(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
-	blueprint := &JenkinsPipelinePlan{}
-	return &plugin.ApiResourceOutput{Body: blueprint, Status: http.StatusOK}, nil
-}
-
-type JenkinsPipelinePlan [][]struct {
-	Plugin   string   `json:"plugin"`
-	Subtasks []string `json:"subtasks"`
-	Options  struct {
-		ConnectionID int `json:"connectionId"`
-	} `json:"options"`
-}
