@@ -150,7 +150,10 @@ func convertURL(api, issueKey string) string {
 	if err != nil {
 		return api
 	}
-	before, _, _ := strings.Cut(u.Path, "/rest/agile/1.0/issue")
+	before, _, found := strings.Cut(u.Path, "/rest/agile/1.0/issue")
+	if !found {
+		before, _, _ = strings.Cut(u.Path, "/rest/api/2/issue")
+	}
 	u.Path = filepath.Join(before, "browse", issueKey)
 	return u.String()
 }
