@@ -43,9 +43,9 @@ var CollectRemotelinksMeta = plugin.SubTaskMeta{
 
 func CollectRemotelinks(taskCtx plugin.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*JiraTaskData)
-	transformationRule := data.Options.TransformationRules
+	scopeConfig := data.Options.ScopeConfig
 	// if the following condition is true, it means that the task is not enabled
-	if transformationRule != nil && transformationRule.ApplicationType != "" {
+	if scopeConfig != nil && scopeConfig.ApplicationType != "" {
 		return nil
 	}
 	db := taskCtx.GetDal()
