@@ -26,5 +26,7 @@ func All() []plugin.MigrationScript {
 		new(modifyCharacterSet),
 		new(expandProjectKey20230206),
 		new(addRawParamTableForScope),
+		new(modifyFileMetricsKeyLength),
+		new(modifyComponentLength),
 	}
 }
