@@ -20,12 +20,11 @@ package api
 import (
 	"fmt"
 	"github.com/apache/incubator-devlake/core/dal"
-	"net/http"
-	"strconv"
-
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/plugins/webhook/models"
+	"net/http"
+	"strconv"
 )
 
 // PostConnections
@@ -40,11 +39,34 @@ import (
 func PostConnections(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
 	// update from request and save to database
 	connection := &models.WebhookConnection{}
-	err := connectionHelper.Create(connection, input)
+	tx := basicRes.GetDal().Begin()
+	err := connectionHelper.CreateWithTx(tx, connection, input)
 	if err != nil {
 		return nil, err
 	}
-	return &plugin.ApiResourceOutput{Body: connection, Status: http.StatusOK}, nil
+	logger.Info("connection: %+v", connection)
+	name := fmt.Sprintf("%s-%d", pluginName, connection.ID)
+	allowedPath := fmt.Sprintf("/plugins/%s/connections/%d/.*", pluginName, connection.ID)
+	extra := fmt.Sprintf("connectionId:%d", connection.ID)
+	apiKeyRecord, err := apiKeyHelper.CreateForPlugin(tx, input.User, name, pluginName, allowedPath, extra)
+	if err != nil {
+		if err := tx.Rollback(); err != nil {
+			logger.Error(err, "transaction Rollback")
+		}
+		logger.Error(err, "CreateForPlugin")
+		return nil, err
+	}
+	if err := tx.Commit(); err != nil {
+		logger.Info("transaction commit: %s", err)
+	}
+
+	apiOutputConnection := models.ApiOutputWebhookConnection{
+		WebhookConnection: *connection,
+		ApiKey:            apiKeyRecord,
+	}
+	logger.Info("api output connection: %+v", apiOutputConnection)
+
+	return &plugin.ApiResourceOutput{Body: apiOutputConnection, Status: http.StatusOK}, nil
 }
 
 // PatchConnection
@@ -79,10 +101,29 @@ func DeleteConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput
 	if e != nil {
 		return nil, errors.BadInput.WrapRaw(e)
 	}
-	err := basicRes.GetDal().Delete(&models.WebhookConnection{}, dal.Where("id = ?", connectionId))
+	var connection models.WebhookConnection
+	tx := basicRes.GetDal().Begin()
+	err := tx.Delete(&connection, dal.Where("id = ?", connectionId))
 	if err != nil {
+		if err := tx.Rollback(); err != nil {
+			logger.Error(err, "transaction Rollback")
+		}
+		logger.Error(err, "delete connection: %d", connectionId)
 		return nil, err
 	}
+	extra := fmt.Sprintf("connectionId:%d", connectionId)
+	err = apiKeyHelper.DeleteForPlugin(tx, pluginName, extra)
+	if err != nil {
+		if err := tx.Rollback(); err != nil {
+			logger.Error(err, "transaction Rollback")
+		}
+		logger.Error(err, "delete connection extra: %d, name: %s", extra, pluginName)
+		return nil, err
+	}
+	if err := tx.Commit(); err != nil {
+		logger.Info("transaction commit: %s", err)
+	}
+
 	return &plugin.ApiResourceOutput{Status: http.StatusOK}, nil
 }
 
@@ -133,10 +174,10 @@ func GetConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, e
 
 func formatConnection(connection *models.WebhookConnection) *WebhookConnectionResponse {
 	response := &WebhookConnectionResponse{WebhookConnection: *connection}
-	response.PostIssuesEndpoint = fmt.Sprintf(`/plugins/webhook/%d/issues`, connection.ID)
-	response.CloseIssuesEndpoint = fmt.Sprintf(`/plugins/webhook/%d/issue/:issueKey/close`, connection.ID)
-	response.PostPipelineTaskEndpoint = fmt.Sprintf(`/plugins/webhook/%d/cicd_tasks`, connection.ID)
-	response.PostPipelineDeployTaskEndpoint = fmt.Sprintf(`/plugins/webhook/%d/deployments`, connection.ID)
-	response.ClosePipelineEndpoint = fmt.Sprintf(`/plugins/webhook/%d/cicd_pipeline/:pipelineName/finish`, connection.ID)
+	response.PostIssuesEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/issues`, connection.ID)
+	response.CloseIssuesEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/issue/:issueKey/close`, connection.ID)
+	response.PostPipelineTaskEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/cicd_tasks`, connection.ID)
+	response.PostPipelineDeployTaskEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/deployments`, connection.ID)
+	response.ClosePipelineEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/cicd_pipeline/:pipelineName/finish`, connection.ID)
 	return response
 }
