@@ -22,6 +22,7 @@ import sys
 import fire
 
 import pydevlake.message as msg
+import pydevlake.model_info
 from pydevlake.subtasks import Subtask
 from pydevlake.logger import logger
 from pydevlake.ipc import PluginCommands
@@ -113,22 +114,18 @@ class Plugin(ABC):
 
     def make_remote_scopes(self, connection: Connection, group_id: Optional[str] = None) -> msg.RemoteScopes:
         if group_id:
-            remote_scopes = []
             for tool_scope in self.remote_scopes(connection, group_id):
                 tool_scope.connection_id = connection.id
                 tool_scope.raw_data_params = raw_data_params(connection.id, tool_scope.id)
                 tool_scope.raw_data_table = self._raw_scope_table_name()
-                remote_scopes.append(
-                    msg.RemoteScope(
+                yield msg.RemoteScope(
                         id=tool_scope.id,
                         parent_id=group_id,
                         name=tool_scope.name,
                         data=tool_scope
                     )
-                )
         else:
-            remote_scopes = self.remote_scope_groups(connection)
-        return msg.RemoteScopes(__root__=remote_scopes)
+            yield from self.remote_scope_groups(connection)
 
     def make_pipeline(self, scope_config_pairs: list[ScopeConfigPair],
                       connection: Connection) -> msg.PipelineData:
@@ -233,10 +230,10 @@ class Plugin(ABC):
             description=self.description,
             plugin_path=self._plugin_path(),
             extension="datasource",
-            connection_model_info=msg.DynamicModelInfo.from_model(self.connection_type),
-            scope_model_info=msg.DynamicModelInfo.from_model(self.tool_scope_type),
-            scope_config_model_info=msg.DynamicModelInfo.from_model(self.scope_config_type),
-            tool_model_infos=[msg.DynamicModelInfo.from_model(stream.tool_model) for stream in self._streams.values()],
+            connection_model_info=pydevlake.model_info.DynamicModelInfo.from_model(self.connection_type),
+            scope_model_info=pydevlake.model_info.DynamicModelInfo.from_model(self.tool_scope_type),
+            scope_config_model_info=pydevlake.model_info.DynamicModelInfo.from_model(self.scope_config_type),
+            tool_model_infos=[pydevlake.model_info.DynamicModelInfo.from_model(stream.tool_model) for stream in self._streams.values()],
             subtask_metas=subtask_metas,
             migration_scripts=MIGRATION_SCRIPTS
         )
