@@ -21,6 +21,7 @@ import (
 	"encoding/json"
 	"fmt"
 	"strings"
+	"sync"
 
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/services"
 
@@ -44,6 +45,8 @@ type BlueprintQuery struct {
 	Enable   *bool  `form:"enable,omitempty"`
 	IsManual *bool  `form:"isManual"`
 	Label    string `form:"label"`
+	// isManual must be omitted or `null` for type to take effect
+	Type string `form:"type" enums:"ALL,MANUAL,DAILY,WEEKLY,MONTHLY,CUSTOM" validate:"oneof=ALL MANUAL DAILY WEEKLY MONTHLY CUSTOM"`
 }
 
 type BlueprintJob struct {
@@ -83,17 +86,14 @@ func CreateBlueprint(blueprint *models.Blueprint) errors.Error {
 
 // GetBlueprints returns a paginated list of Blueprints based on `query`
 func GetBlueprints(query *BlueprintQuery) ([]*models.Blueprint, int64, errors.Error) {
-	blueprints, count, err := bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
+	return bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
 		Enable:      query.Enable,
 		IsManual:    query.IsManual,
 		Label:       query.Label,
 		SkipRecords: query.GetSkip(),
 		PageSize:    query.GetPageSize(),
+		Type:        query.Type,
 	})
-	if err != nil {
-		return nil, 0, errors.Convert(err)
-	}
-	return blueprints, count, nil
 }
 
 // GetBlueprint returns the detail of a given Blueprint ID
@@ -162,19 +162,14 @@ func validateBlueprintAndMakePlan(blueprint *models.Blueprint) errors.Error {
 		}
 	}
 	if blueprint.Mode == models.BLUEPRINT_MODE_ADVANCED {
-		plan := make(plugin.PipelinePlan, 0)
-		err = errors.Convert(json.Unmarshal(blueprint.Plan, &plan))
-		if err != nil {
-			return errors.Default.Wrap(err, "invalid plan")
+		if len(blueprint.Plan) == 0 {
+			return errors.BadInput.New("invalid plan")
 		}
 	} else if blueprint.Mode == models.BLUEPRINT_MODE_NORMAL {
-		plan, err := MakePlanForBlueprint(blueprint, false)
+		var e errors.Error
+		blueprint.Plan, e = MakePlanForBlueprint(blueprint, false)
 		if err != nil {
-			return errors.Default.Wrap(err, "make plan for blueprint failed")
-		}
-		blueprint.Plan, err = errors.Convert01(json.Marshal(plan))
-		if err != nil {
-			return errors.Default.Wrap(err, "failed to markshal plan")
+			return e
 		}
 	}
 	return nil
@@ -239,8 +234,15 @@ func DeleteBlueprint(id uint64) errors.Error {
 	return nil
 }
 
+var blueprintReloadLock sync.Mutex
+
 // ReloadBlueprints FIXME ...
-func ReloadBlueprints(c *cron.Cron) errors.Error {
+func ReloadBlueprints(c *cron.Cron) (err errors.Error) {
+	// preventing concurrent reloads. It would be better to use Table Lock , however, it requires massive refactor
+	// like the `bpManager` must accept transaction. Use mutex as a temporary fix.
+	blueprintReloadLock.Lock()
+	defer blueprintReloadLock.Unlock()
+
 	enable := true
 	isManual := false
 	blueprints, _, err := bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
@@ -276,12 +278,12 @@ func createPipelineByBlueprint(blueprint *models.Blueprint, skipCollectors bool)
 	var err errors.Error
 	if blueprint.Mode == models.BLUEPRINT_MODE_NORMAL {
 		plan, err = MakePlanForBlueprint(blueprint, skipCollectors)
+		if err != nil {
+			blueprintLog.Error(err, fmt.Sprintf("failed to MakePlanForBlueprint on blueprint:[%d][%s]", blueprint.ID, blueprint.Name))
+			return nil, err
+		}
 	} else {
-		plan, err = blueprint.UnmarshalPlan()
-	}
-	if err != nil {
-		blueprintLog.Error(err, fmt.Sprintf("failed to MakePlanForBlueprint on blueprint:[%d][%s]", blueprint.ID, blueprint.Name))
-		return nil, err
+		plan = blueprint.Plan
 	}
 	newPipeline := models.NewPipeline{}
 	newPipeline.Plan = plan
