@@ -66,7 +66,7 @@ func pipelineServiceInit() {
 	if temporalUrl != "" {
 		// TODO: logger
 		var err error
-		temporalClient, err = client.NewClient(client.Options{
+		temporalClient, err = client.NewLazyClient(client.Options{
 			HostPort: temporalUrl,
 		})
 		if err != nil {
@@ -508,19 +508,11 @@ func RerunPipeline(pipelineId uint64, task *models.Task) (tasks []*models.Task,
 			return nil, err
 		}
 		// create new task
-		subtasks, err := t.GetSubTasks()
-		if err != nil {
-			return nil, err
-		}
-		options, err := t.GetOptions()
-		if err != nil {
-			return nil, err
-		}
 		rerunTask, err := CreateTask(&models.NewTask{
 			PipelineTask: &plugin.PipelineTask{
 				Plugin:   t.Plugin,
-				Subtasks: subtasks,
-				Options:  options,
+				Subtasks: t.Subtasks,
+				Options:  t.Options,
 			},
 			PipelineId:  t.PipelineId,
 			PipelineRow: t.PipelineRow,
