@@ -22,7 +22,6 @@ export * from './buttons';
 export * from './card';
 export * from './dialog';
 export * from './divider';
-export { default as ErrorBoundary } from './error-boundary';
 export * from './form';
 export * from './inspector';
 export * from './loading';
@@ -30,6 +29,7 @@ export * from './logo';
 export * from './message';
 export * from './no-data';
 export * from './page-header';
+export * from './pagination';
 export * from './selector';
 export * from './table';
 export * from './toast';
