@@ -110,7 +110,7 @@ export const MultiSelector = <T,>({
   };
 
   const handleQueryChange = (query: string) => {
-    if (onQueryChange) {
+    if (onQueryChange && query) {
       onQueryChange(query);
     } else {
       setQuery(query);
@@ -119,8 +119,8 @@ export const MultiSelector = <T,>({
 
   return (
     <MultiSelect2
-      fill
       resetOnSelect
+      fill
       placeholder={placeholder ?? 'Select...'}
       items={filteredItems}
       // https://github.com/palantir/blueprint/issues/3596
