@@ -18,6 +18,8 @@
 
 import { request } from '@/utils';
 
+export const getProject = (pname: string) => request(`/projects/${pname}`);
+
 export const getBlueprint = (id: ID) => request(`/blueprints/${id}`);
 
 export const updateBlueprint = (id: ID, payload: any) =>
@@ -26,5 +28,8 @@ export const updateBlueprint = (id: ID, payload: any) =>
 export const getConnection = (plugin: string, connectionId: ID) =>
   request(`/plugins/${plugin}/connections/${connectionId}`);
 
-export const getDataScope = (plugin: string, connectionId: ID, scopeId: ID) =>
-  request(`/plugins/${plugin}/connections/${connectionId}/scopes/${scopeId}`);
+export const getDataScopes = (plugin: string, connectionId: ID) =>
+  request(`/plugins/${plugin}/connections/${connectionId}/scopes`);
+
+export const runBlueprint = (id: ID, skipCollectors: boolean) =>
+  request(`/blueprints/${id}/trigger`, { method: 'post', data: { skipCollectors } });
