@@ -52,7 +52,7 @@ export const BlueprintConnectionDetailPage = () => {
 
   const { ready, data } = useRefreshData(async () => {
     const [plugin, connectionId] = unique.split('-');
-    const [blueprint, connection, scopes] = await Promise.all([
+    const [blueprint, connection, scopesRes] = await Promise.all([
       getBlueprint(pname, bid),
       API.getConnection(plugin, connectionId),
       API.getDataScopes(plugin, connectionId),
@@ -70,7 +70,7 @@ export const BlueprintConnectionDetailPage = () => {
         id: +connectionId,
         name: connection.name,
       },
-      scopes: scopes.filter((sc: any) => scopeIds.includes(getPluginScopeId(plugin, sc))),
+      scopes: scopesRes.scopes.filter((sc: any) => scopeIds.includes(getPluginScopeId(plugin, sc))),
     };
   }, [version, pname, bid]);
 
@@ -212,8 +212,9 @@ export const BlueprintConnectionDetailPage = () => {
         columns={[
           {
             title: 'Data Scope',
-            dataIndex: 'name',
+            dataIndex: ['fullName', 'name'],
             key: 'name',
+            render: ({ fullName, name }) => fullName ?? name,
           },
           {
             title: 'Scope Config',
