@@ -16,5 +16,7 @@
  *
  */
 
+export * from './types';
+export * from './utils';
 export * from './home';
 export * from './detail';
