@@ -20,4 +20,8 @@ import styled from 'styled-components';
 
 export const Wrapper = styled.div`
   margin-top: 24px;
+
+  .search {
+    margin-bottom: 16px;
+  }
 `;
