@@ -17,10 +17,11 @@
  */
 
 export * from './connection-form';
-export * from './data-scope';
-export * from './data-scope-form';
+export * from './connection-list';
+export * from './connection-status';
 export * from './data-scope-miller-columns';
 export * from './data-scope-search';
-export * from './transformation';
-export * from './transformation-form';
-export * from './transformation-select';
+export * from './data-scope-select';
+export * from './data-scope-select-remote';
+export * from './scope-config-form';
+export * from './scope-config-select';
