@@ -18,3 +18,5 @@
 
 export * from './token';
 export * from './graphql';
+export * from './githubapp';
+export * from './authentication';
