@@ -29,3 +29,26 @@ export const getBoards = (prefix: string, params: GetBoardsParams) =>
 export const getIssueType = (prefix: string) => request(`${prefix}/api/2/issuetype`);
 
 export const getField = (prefix: string) => request(`${prefix}/api/2/field`);
+
+export const getApplicationTypes = (connectionId: ID, query: { key: string }) =>
+  request(`/plugins/jira/connections/${connectionId}/application-types`, {
+    data: query,
+  });
+
+export const getDevPanelCommits = (connectionId: ID, query: { key: string; applicationType: string }) =>
+  request(`/plugins/jira/connections/${connectionId}/dev-panel-commits`, { data: query });
+
+export const generateRegex = (pattern: string) =>
+  request('/plugins/jira/generate-regex', {
+    method: 'post',
+    data: { pattern },
+  });
+
+export const applyRegex = (regex: string, urls: string[]) =>
+  request('/plugins/jira/apply-regex', {
+    method: 'post',
+    data: {
+      regex,
+      urls,
+    },
+  });
