@@ -16,16 +16,26 @@
  *
  */
 
-import type { PluginConfigType } from '@/plugins';
-import { PluginType } from '@/plugins';
+import type { PluginConfigType } from '../../types';
+import { PluginType } from '../../types';
 
 import Icon from './assets/icon.svg';
-import { BasePipelineConfig } from '../base';
 
 export const WebhookConfig: PluginConfigType = {
-  ...BasePipelineConfig,
   plugin: 'webhook',
   name: 'Webhook',
-  type: PluginType.Incoming_Connection,
+  type: PluginType.Connection,
   icon: Icon,
+  sort: 100,
+  connection: {
+    docLink: '',
+    fields: [],
+    initialValues: {},
+  },
+  dataScope: {
+    millerColumns: {
+      title: '',
+      subTitle: '',
+    },
+  },
 };
